CollapseId

Struct CollapseId 

pub struct CollapseId(/* private fields */);
Wrapper type for collapse ids. It may be an arbitrary string, but is limited in length to at most 63 bytes.

Implementations

Source

impl CollapseId

pub fn new(value: String) -> Result<Self, CollapseIdTooLongError>

Construct a new collapse id. Returns an error if id exceeds the maximum length of 64 bytes.

pub fn as_str(&self) -> &str

Get id as a raw str.