pub struct Notification<'a> {
pub topic: &'a str,
pub device_token: &'a str,
pub payload: Payload<'a>,
pub id: Option<Uuid>,
pub expiration: Option<u64>,
pub priority: Option<Priority>,
pub collapse_id: Option<CollapseId>,
pub apns_push_type: Option<ApnsPushType>,
}Expand description
A notification struct contains all relevant data for a notification request sent to the APNS API. This includes other options not contained in the payload. These options are transferred with HTTP request headers.
Fields
topic: &'a strThe topic to use. Usually the app bundle id.
device_token: &'a strpayload: Payload<'a>id: Option<Uuid>Optional id identifying the message.
expiration: Option<u64>Optional expiration time as UNIX timestamp.
priority: Option<Priority>Priority for the notification.
collapse_id: Option<CollapseId>apns_push_type: Option<ApnsPushType>Implementations